@@ -2,7 +2,7 @@
  * @file gnome-cmd-con-list.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2018 Uwe Scholz\n
+ * @copyright (C) 2013-2019 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,13 +39,13 @@ struct GnomeCmdConList::Private
     gboolean device_cons_changed;
     gboolean quick_ftp_cons_changed;
 
-    GList *remote_cons;
-    GList *device_cons;
-    GList *quick_ftp_cons;
+    GList *remote_cons    {nullptr};
+    GList *device_cons    {nullptr};
+    GList *quick_ftp_cons {nullptr};
 
-    GnomeCmdCon *home_con;
+    GnomeCmdCon *home_con {nullptr};
 #ifdef HAVE_SAMBA
-    GnomeCmdCon *smb_con;
+    GnomeCmdCon *smb_con  {nullptr};
 #endif
     GList *all_cons;
 };
@@ -152,9 +152,6 @@ static void init (GnomeCmdConList *con_list)
 #ifdef HAVE_SAMBA
     con_list->priv->smb_con = gnome_cmd_con_smb_new ();
 #endif
-    // con_list->priv->remote_cons = NULL;
-    // con_list->priv->device_cons = NULL;
-    // con_list->priv->quick_ftp_cons = NULL;
     con_list->priv->all_cons = g_list_append (NULL, con_list->priv->home_con);
 #ifdef HAVE_SAMBA
     con_list->priv->all_cons = g_list_append (con_list->priv->all_cons, con_list->priv->smb_con);
