@@ -2,7 +2,7 @@
  * @file gnome-cmd-con-remote.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2018 Uwe Scholz\n
+ * @copyright (C) 2013-2019 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -145,6 +145,12 @@ static GnomeCmdPath *remote_create_path (GnomeCmdCon *con, const gchar *path_str
 
 static void destroy (GtkObject *object)
 {
+    GnomeCmdConRemote *con_remote = GNOME_CMD_CON_REMOTE (object);
+
+    gnome_cmd_pixmap_free (con_remote->parent.go_pixmap);
+    gnome_cmd_pixmap_free (con_remote->parent.open_pixmap);
+    gnome_cmd_pixmap_free (con_remote->parent.close_pixmap);
+
     if (GTK_OBJECT_CLASS (parent_class)->destroy)
         (*GTK_OBJECT_CLASS (parent_class)->destroy) (object);
 }
