@@ -2,7 +2,7 @@
  * @file gnome-cmd-con.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2018 Uwe Scholz\n
+ * @copyright (C) 2013-2019 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -95,6 +95,7 @@ static void destroy (GtkObject *object)
     g_free (con->close_text);
     g_free (con->close_tooltip);
     gnome_cmd_pixmap_free (con->close_pixmap);
+    gnome_cmd_pixmap_free (con->go_pixmap);
 
     if (con->priv->default_dir)
         gnome_cmd_dir_unref (con->priv->default_dir);
@@ -599,18 +600,3 @@ std::string &gnome_cmd_con_make_smb_uri (std::string &s, gboolean use_auth, std:
     return s;
 }
 #endif
-
-
-XML::xstream &operator << (XML::xstream &xml, GnomeCmdCon &con)
-{
-    if (!con.alias || !*con.alias || !con.uri || !*con.uri)
-        return xml;
-
-    xml << XML::tag("Connection");
-
-    xml << XML::attr("name") << XML::escape(con.alias);
-    xml << XML::attr("uri") << XML::escape(con.uri);
-    xml << XML::attr("auth") << con.auth;
-
-    return xml << XML::endtag();
-}
