@@ -2,7 +2,7 @@
  * @file gnome-cmd-data.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2018 Uwe Scholz\n
+ * @copyright (C) 2013-2019 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -113,6 +113,36 @@ GcmdSettings *gcmd_settings_new (void);
 #define GCMD_SETTINGS_COLUMN_WIDTH_PERM               "column-width-perm"
 #define GCMD_SETTINGS_COLUMN_WIDTH_OWNER              "column-width-owner"
 #define GCMD_SETTINGS_COLUMN_WIDTH_GROUP              "column-width-group"
+#define GCMD_SETTINGS_ADVRENAME_TOOL_WIDTH            "advrename-win-width"
+#define GCMD_SETTINGS_ADVRENAME_TOOL_HEIGHT           "advrename-win-height"
+#define GCMD_SETTINGS_ADVRENAME_TOOL_TEMPLATE_HISTORY "advrename-template-history"
+#define GCMD_SETTINGS_ADVRENAME_PROFILES              "advrename-profiles"
+#define GCMD_SETTINGS_ADVRENAME_PROFILE_FORMAT_STRING "(ssuiuuuasasab)"
+#define GCMD_SETTINGS_ADVRENAME_PROFILES_FORMAT_STRING "a(ssuiuuuasasab)"
+#define GCMD_SETTINGS_FILE_LIST_TABS                  "file-list-tabs"
+#define GCMD_SETTINGS_FILE_LIST_TAB_FORMAT_STRING     "(syybb)"
+#define GCMD_SETTINGS_DEVICES                         "devices"
+#define GCMD_SETTINGS_DEVICES_FORMAT_STRING           "(ssss)"
+#define GCMD_SETTINGS_FAV_APPS                        "favorite-apps"
+#define GCMD_SETTINGS_FAV_APPS_FORMAT_STRING          "(ssssubbb)"
+#define GCMD_SETTINGS_DIRECTORY_HISTORY               "directory-history"
+#define GCMD_SETTINGS_SEARCH_WIN_WIDTH                "search-win-width"
+#define GCMD_SETTINGS_SEARCH_WIN_HEIGHT               "search-win-height"
+#define GCMD_SETTINGS_SEARCH_PATTERN_HISTORY          "search-pattern-history"
+#define GCMD_SETTINGS_SEARCH_TEXT_HISTORY             "search-text-history"
+#define GCMD_SETTINGS_SEARCH_PROFILES                 "search-profiles"
+#define GCMD_SETTINGS_SEARCH_PROFILE_FORMAT_STRING    "(siisbbs)"
+#define GCMD_SETTINGS_SEARCH_PROFILES_FORMAT_STRING   "a(siisbbs)"
+#define GCMD_SETTINGS_BOOKMARKS                       "bookmarks"
+#define GCMD_SETTINGS_BOOKMARK_FORMAT_STRING          "(bsss)"
+#define GCMD_SETTINGS_BOOKMARKS_FORMAT_STRING         "a(bsss)"
+#define GCMD_SETTINGS_BOOKMARKS_WINDOW_WIDTH          "bookmarks-win-width"
+#define GCMD_SETTINGS_BOOKMARKS_WINDOW_WIDTH          "bookmarks-win-width"
+#define GCMD_SETTINGS_BOOKMARKS_WINDOW_HEIGHT         "bookmarks-win-height"
+#define GCMD_SETTINGS_CONNECTIONS                     "connections"
+#define GCMD_SETTINGS_CONNECTION_FORMAT_STRING        "(ss)"
+#define GCMD_SETTINGS_KEYBINDINGS                     "keybindings"
+#define GCMD_SETTINGS_KEYBINDING_FORMAT_STRING        "(sssbbbbbb)"
 
 #define GCMD_PREF_FILTER                              "org.gnome.gnome-commander.preferences.filter"
 #define GCMD_SETTINGS_FILTER_HIDE_UNKNOWN             "hide-unknown"
@@ -198,6 +228,26 @@ GcmdSettings *gcmd_settings_new (void);
 #define GCMD_PREF_PLUGINS                             "org.gnome.gnome-commander.plugins.general"
 #define GCMD_SETTINGS_PLUGINS_AUTOLOAD                "autoload"
 
+//gKeyFile constants
+#define DEVICES_FILENAME                              "devices"
+#define DEVICES_DEVICE                                "device"
+#define DEVICES_MOUNT_POINT                           "mount_point"
+#define DEVICES_ICON_PATH                             "icon_path"
+#define FAV_APPS_FILENAME                             "fav-apps"
+#define FAV_APPS_CMD                                  "cmd"
+#define FAV_APPS_ICON                                 "icon"
+#define FAV_APPS_PATTERN                              "pattern"
+#define FAV_APPS_TARGET                               "target"
+#define FAV_APPS_HANDLES_URIS                         "handles_uris"
+#define FAV_APPS_HANDLES_MULTIPLE                     "handles_multiple"
+#define FAV_APPS_REQUIRES_TERMINAL                    "requires_terminal"
+#define TABS_LAYOUT_FILENAME                          "file-list-tabs"
+#define TAB_PATH                                      "path"
+#define TAB_FILESLECTORID                             "fileSelectorId"
+#define TAB_SORT                                      "sort"
+#define TAB_ASC                                       "asc"
+#define TAB_LOCK                                      "lock"
+
 struct GnomeCmdConRemote;
 
 struct GnomeCmdData
@@ -480,39 +530,43 @@ struct GnomeCmdData
         void on_size_display_mode_changed();
     };
 
-    struct Selection
+    struct SearchProfile
     {
         std::string name;
         std::string filename_pattern;
-        Filter::Type syntax;
-        int max_depth;
+        Filter::Type syntax {Filter::TYPE_REGEX};
+        int max_depth {-1};
         std::string text_pattern;
-        gboolean content_search;
-        gboolean match_case;
-
-        Selection(): syntax(Filter::TYPE_REGEX), max_depth(-1), content_search(FALSE), match_case(FALSE)       {}
-        ~Selection() {}
+        gboolean content_search {FALSE};
+        gboolean match_case {FALSE};
 
         const std::string &description() const    {  return filename_pattern;  }
         void reset();
 
-        friend XML::xstream &operator << (XML::xstream &xml, Selection &cfg);
+        ~SearchProfile();
     };
 
     struct SearchConfig
     {
         gint width, height;
 
-        Selection default_profile;
+        SearchProfile default_profile;
 
         History name_patterns;
         History content_patterns;
 
-        std::vector<Selection> &profiles;
+        std::vector<SearchProfile> &profiles;
 
-        explicit SearchConfig(std::vector<Selection> &selections): width(600), height(400), name_patterns(SEARCH_HISTORY_SIZE), content_patterns(SEARCH_HISTORY_SIZE), profiles(selections)   {  default_profile.name = "Default";  }
+        explicit SearchConfig(std::vector<SearchProfile> &searchProfiles):
+            width(600),
+            height(400),
+            name_patterns(SEARCH_HISTORY_SIZE),
+            content_patterns(SEARCH_HISTORY_SIZE),
+            profiles(searchProfiles)
+        {
+            default_profile.name = "Default";
+        }
 
-        friend XML::xstream &operator << (XML::xstream &xml, SearchConfig &cfg);
         ~SearchConfig() {};
     };
 
@@ -521,23 +575,20 @@ struct GnomeCmdData
         struct Profile
         {
             std::string name;
-            std::string template_string;
-            guint counter_start;
-            guint counter_width;
-            gint counter_step;
+            std::string template_string {"$N"};
+            guint counter_start {1};
+            guint counter_width {1};
+            gint counter_step   {1};
 
             std::vector<GnomeCmd::ReplacePattern> regexes;
 
-            guint case_conversion;
-            guint trim_blanks;
-
-            Profile(): template_string("$N"),
-                       counter_start(1), counter_width(1), counter_step(1),
-                       case_conversion(0), trim_blanks(3)                     {}
-            ~Profile()                                                        {}
+            guint case_conversion {0};
+            guint trim_blanks {3};
 
             const std::string &description() const {  return template_string;  }
             void reset();
+
+            ~Profile();
         };
 
         gint width, height;
@@ -549,8 +600,6 @@ struct GnomeCmdData
 
         AdvrenameConfig(): width(600), height(400), templates(ADVRENAME_HISTORY_SIZE)   {}
         ~AdvrenameConfig()                                                              {}
-
-        friend XML::xstream &operator << (XML::xstream &xml, AdvrenameConfig &cfg);
     };
 
     struct IntViewerConfig
@@ -567,11 +616,7 @@ struct GnomeCmdData
 
     struct BookmarksConfig
     {
-        gint width, height;
-
-        BookmarksConfig(): width(400), height(250)   {}
-
-        friend XML::xstream &operator << (XML::xstream &xml, BookmarksConfig &cfg);
+        gint width {400}, height {250};
     };
 
     typedef std::pair<std::string,triple<GnomeCmdFileList::ColumnID,GtkSortType,gboolean> > Tab;
@@ -588,29 +633,35 @@ struct GnomeCmdData
 
     void load_auto_load_plugins();
     void load_cmdline_history();
-    void load_rename_history();
+    void load_directory_history();
     void load_intviewer_defaults();
     gboolean save_auto_load_plugins();
+    void load_bookmarks();
+    void load_keybindings();
+    void save_keybindings();
+    void load_connections();
+    void save_connections();
     void save_cmdline_history();
+    void save_directory_history();
+    void save_search_history();
     void save_intviewer_defaults();
-    void set_settings_monitor (const char *file_path);
+    void save_devices_via_gsettings();
+    void save_fav_apps_via_gsettings();
+    void add_advrename_profile_to_gvariant_builder(GVariantBuilder *builder, AdvrenameConfig::Profile profile);
+    gboolean add_bookmark_to_gvariant_builder(GVariantBuilder *builder, std::string bookmarkName, GnomeCmdCon *con);
+    void add_search_profile_to_gvariant_builder(GVariantBuilder *builder, SearchProfile searchProfile);
     inline gint get_int (const gchar *path, int def);
-    inline void set_int (const gchar *path, int value);
     inline gchar* get_string (const gchar *path, const gchar *def);
     inline void set_string (const gchar *path, const gchar *value);
     inline gboolean get_bool (const gchar *path, gboolean def);
-    inline void set_bool (const gchar *path, gboolean value);
     inline void set_color (const gchar *path, GdkColor *color);
 
   public:
 
-    gboolean                     XML_cfg_has_connections;
-    gboolean                     XML_cfg_has_bookmarks;
-
     Options                      options;
     GcmdSettings                 *settings;
 
-    std::vector<Selection>       selections;
+    std::vector<SearchProfile>   profiles;
 
     SearchConfig                 search_defaults;
     AdvrenameConfig              advrename_defaults;
@@ -649,23 +700,29 @@ struct GnomeCmdData
 
     GnomeCmdData();
 
-    void free();                // FIXME: free() -> ~GnomeCmdData()
+    ~GnomeCmdData();
 
     void load();
+    void load_colors();
+    void load_color_themes();
+    void load_tabs_from_gsettings();
+    void load_devices_from_gsettings();
+    void load_fav_apps_from_gsettings();
     void gsettings_init();
     void migrate_all_data_to_gsettings();
     gint migrate_data_int_value_into_gsettings(gint user_value, GSettings *settings, const char *key);
     gboolean migrate_data_string_value_into_gsettings(const char* user_value, GSettings *settings, const char *key);
     void load_more();
     inline GList* load_string_history (const gchar *format, gint size);
+    void load_advrename_profiles ();
+    void save_advrename_profiles ();
+    void load_search_profiles ();
+    void save_search_profiles ();
+    void save_bookmarks();
     void save();
-    void save_xml ();
     gint gnome_cmd_data_get_int (const gchar *path, int def);
-    void gnome_cmd_data_set_int (const gchar *path, int value);
     gchar* gnome_cmd_data_get_string (const gchar *path, const gchar *def);
     void gnome_cmd_data_set_string (const gchar *path, const gchar *value);
-    void gnome_cmd_data_set_bool (const gchar *path, gboolean value);
-    void gnome_cmd_data_set_color (const gchar *path, GdkColor *color);
     gboolean gnome_cmd_data_parse_color (const gchar *spec, GdkColor *color);
     gboolean set_color_if_valid_key_value(GdkColor *color, GSettings *settings, const char *key);
     void gnome_cmd_data_get_color_gnome_config (const gchar *path, GdkColor *color);
@@ -673,7 +730,6 @@ struct GnomeCmdData
     gboolean set_gsettings_when_changed (GSettings *settings, const char *key, gpointer value);
     gboolean set_gsettings_color_when_changed (GSettings *settings, const char *key, GdkColor *color);
     gboolean set_gsettings_enum_when_changed (GSettings *settings, const char *key, gint value);
-    inline void gnome_cmd_data_set_string_history (const gchar *format, GList *strings);
     gboolean is_valid_color_string(const char *colorstring);
     gboolean set_valid_color_string(GSettings *settings, const char* key);
 
