@@ -2,7 +2,7 @@
  * @file gnome-cmd-dir.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2018 Uwe Scholz\n
+ * @copyright (C) 2013-2019 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -117,11 +117,7 @@ inline GnomeCmdDir *gnome_cmd_dir_ref (GnomeCmdDir *dir)
     return dir;
 }
 
-inline void gnome_cmd_dir_unref (GnomeCmdDir *dir)
-{
-    g_return_if_fail (GNOME_CMD_IS_DIR (dir));
-    GNOME_CMD_FILE (dir)->unref();
-}
+void gnome_cmd_dir_unref (GnomeCmdDir *dir);
 
 GList *gnome_cmd_dir_get_files (GnomeCmdDir *dir);
 void gnome_cmd_dir_relist_files (GnomeCmdDir *dir, gboolean visprog);
