@@ -2,7 +2,7 @@
  * @file gnome-cmd-file-popmenu.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2018 Uwe Scholz\n
+ * @copyright (C) 2013-2019 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -515,6 +515,11 @@ static void class_init (GnomeCmdFilePopmenuClass *klass)
 static void init (GnomeCmdFilePopmenu *menu)
 {
     menu->priv = g_new0 (GnomeCmdFilePopmenuPrivate, 1);
+
+    // Create scripts directory if needed
+    gchar *scripts_dir = g_build_filename (g_get_user_config_dir (), PACKAGE "/scripts", NULL);
+    create_dir_if_needed(scripts_dir);
+    g_free (scripts_dir);
 }
 
 
@@ -735,7 +740,7 @@ GtkWidget *gnome_cmd_file_popmenu_new (GnomeCmdFileList *fl)
         gnome_app_fill_menu (GTK_MENU_SHELL (menu), sep_uiinfo, NULL, FALSE, pos++);
 
     // Script actions
-    gchar *user_dir = g_build_filename (g_get_home_dir (), "." PACKAGE "/scripts", NULL);
+    gchar *user_dir = g_build_filename (g_get_user_config_dir (), PACKAGE "/scripts", NULL);
     DIR *dp = opendir (user_dir);
     GList *script_list = NULL;
     if (dp != NULL)
