@@ -2,7 +2,7 @@
  * @file gnome-cmd-file-selector.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2018 Uwe Scholz\n
+ * @copyright (C) 2013-2019 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -811,7 +811,6 @@ static void init (GnomeCmdFileSelector *fs)
 
     for (GList *l=gnome_cmd_con_list_get_all (gnome_cmd_con_list_get ()); l; l = l->next)
     {
-        gchar *text;
         GnomeCmdCon *con = (GnomeCmdCon *) l->data;
 
 #ifdef HAVE_SAMBA
@@ -821,10 +820,9 @@ static void init (GnomeCmdFileSelector *fs)
         if (!gnome_cmd_con_is_open (con) && !GNOME_CMD_IS_CON_DEVICE (con))  continue;
 #endif
 
-        text = g_strdup_printf("%s  ",(gchar *) gnome_cmd_con_get_alias (con));
-        string_size = get_string_pixel_size (text, strlen(text));
+        string textstring {gnome_cmd_con_get_alias (con)};
+        string_size = get_string_pixel_size (textstring.c_str(), textstring.length());
         max_string_size = string_size > max_string_size ? string_size : max_string_size;
-        g_free(text);
     }
 
     // create the connection combo
@@ -1599,37 +1597,9 @@ void GnomeCmdFileSelector::update_tab_label(GnomeCmdFileList *fl)
 }
 
 
-XML::xstream &operator << (XML::xstream &xml, GnomeCmdFileSelector &fs)
+GList* GnomeCmdFileSelector::GetTabs()
 {
-    GList *tabs = gtk_container_get_children (*fs.notebook);
+    GList *tabs = gtk_container_get_children (*this->notebook);
 
-    if (gnome_cmd_data.options.save_tabs_on_exit)
-        for (GList *i=tabs; i; i=i->next)
-        {
-            GnomeCmdFileList *fl = (GnomeCmdFileList *) gtk_bin_get_child (GTK_BIN (i->data));
-
-            if (GNOME_CMD_FILE_LIST (fl) && gnome_cmd_con_is_local (fl->con))
-                xml << *fl;
-        }
-    else
-        if (gnome_cmd_data.options.save_dirs_on_exit)
-            for (GList *i=tabs; i; i=i->next)
-            {
-                GnomeCmdFileList *fl = (GnomeCmdFileList *) gtk_bin_get_child (GTK_BIN (i->data));
-
-                if (GNOME_CMD_FILE_LIST (fl) && gnome_cmd_con_is_local (fl->con) && (fl==fs.file_list() || fl->locked))
-                    xml << *fl;
-            }
-        else
-            for (GList *i=tabs; i; i=i->next)
-            {
-                GnomeCmdFileList *fl = (GnomeCmdFileList *) gtk_bin_get_child (GTK_BIN (i->data));
-
-                if (GNOME_CMD_FILE_LIST (fl) && gnome_cmd_con_is_local (fl->con) && fl->locked)
-                    xml << *fl;
-            }
-
-    g_list_free (tabs);
-
-    return xml;
-}
+    return tabs;
+}
\ No newline at end of file
