@@ -2,7 +2,7 @@
  * @file gnome-cmd-file-selector.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2018 Uwe Scholz\n
+ * @copyright (C) 2013-2019 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -94,6 +94,7 @@ struct GnomeCmdFileSelector
     void close_tab(gint n)                  {  if (notebook->size()>1)  notebook->remove_page(n);  }
 
     void update_tab_label(GnomeCmdFileList *fl);
+    GnomeCmdFileList get_gnome_cmd_file_list(GnomeCmdFileSelector &fs);
 
     void show_filter();
     void update_files();
@@ -109,7 +110,7 @@ struct GnomeCmdFileSelector
 
     gboolean key_pressed(GdkEventKey *event);
 
-    friend XML::xstream &operator << (XML::xstream &xml, GnomeCmdFileSelector &fs);
+    GList* GetTabs();
 };
 
 inline GnomeCmdFileList *GnomeCmdFileSelector::file_list(gint n) const
