@@ -2,7 +2,7 @@
  * @file gnome-cmd-main-win.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2018 Uwe Scholz\n
+ * @copyright (C) 2013-2019 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1425,16 +1425,3 @@ void GnomeCmdMainWin::maximize_pane()
     else
         slide_set_0_100 (NULL, NULL);
 }
-
-
-XML::xstream &operator << (XML::xstream &xml, GnomeCmdMainWin &mw)
-{
-    xml << XML::tag("Layout");
-
-        xml << XML::tag("Panel") << XML::attr("name") << "left" << *mw.fs(LEFT) << XML::endtag();
-        xml << XML::tag("Panel") << XML::attr("name") << "right" << *mw.fs(RIGHT) << XML::endtag();
-
-    xml << XML::endtag();
-
-    return xml;
-}
