@@ -2,7 +2,7 @@
  * @file gnome-cmd-user-actions.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2018 Uwe Scholz\n
+ * @copyright (C) 2013-2019 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -479,9 +479,9 @@ void GnomeCmdUserActions::shutdown()
 }
 
 
-gboolean GnomeCmdUserActions::register_action(guint state, guint keyval, const gchar *action_name, const char *user_data)
+gboolean GnomeCmdUserActions::register_action(guint state, guint keyval, const gchar *the_action_name, const char *user_data)
 {
-    GnomeCmdUserActionFunc func = action_func[action_name];
+    GnomeCmdUserActionFunc func = action_func[the_action_name];
 
     if (!func)
         return FALSE;
@@ -507,7 +507,7 @@ gboolean GnomeCmdUserActions::register_action(guint state, guint keyval, const g
 }
 
 
-void GnomeCmdUserActions::unregister(const gchar *action_name)
+void GnomeCmdUserActions::unregister(const gchar *the_action_name)
 {
 }
 
@@ -525,9 +525,9 @@ void GnomeCmdUserActions::unregister(guint state, guint keyval)
 }
 
 
-gboolean GnomeCmdUserActions::registered(const gchar *action_name)
+gboolean GnomeCmdUserActions::registered(const gchar *the_action_name)
 {
-    GnomeCmdUserActionFunc func = action_func[action_name];
+    GnomeCmdUserActionFunc func = action_func[the_action_name];
 
     if (!func)
         return FALSE;
@@ -566,40 +566,6 @@ gboolean GnomeCmdUserActions::handle_key_event(GnomeCmdMainWin *mw, GnomeCmdFile
     return TRUE;
 }
 
-XML::xstream &operator << (XML::xstream &xml, GnomeCmdUserActions &usr)
-{
-    xml << XML::tag("KeyBindings");
-    for (GnomeCmdUserActions::ACTIONS_COLL::const_iterator i=usr.action.begin(); i!=usr.action.end(); ++i)
-        if (!ascii_isupper (i->first))                                         // ignore lowercase keys as they duplicate uppercase ones
-        {
-            guint state = i->first.state;
-            guint key_val = i->first.keyval;
-
-            xml << XML::tag("Key") << XML::attr("name");
-            if (ascii_isalnum (key_val))
-                xml << (gchar) key_val;
-            else
-                xml << gdk_key_names[key_val];
-
-            if (state & GDK_SHIFT_MASK)    xml << XML::attr("shift") << 1;
-            if (state & GDK_CONTROL_MASK)  xml << XML::attr("control") << 1;
-            if (state & GDK_MOD1_MASK)     xml << XML::attr("alt") << 1;
-            if (state & GDK_SUPER_MASK)    xml << XML::attr("super") << 1;
-            if (state & GDK_HYPER_MASK)    xml << XML::attr("hyper") << 1;
-            if (state & GDK_META_MASK)     xml << XML::attr("meta") << 1;
-
-            xml << XML::attr("action") << usr.action_func[i->second.func];
-            if (!i->second.user_data.empty())
-                xml << XML::attr("options") << XML::escape(i->second.user_data);
-
-            xml << XML::endtag();
-        }
-
-    xml << XML::endtag();
-
-    return xml;
-}
-
 
 static int sort_by_description (const void *data1, const void *data2)
 {
@@ -1976,7 +1942,7 @@ void help_problem (GtkMenuItem *menuitem, gpointer not_used)
 {
     GError *error = NULL;
 
-    if (!gtk_show_uri (NULL, "http://bugzilla.gnome.org/browse.cgi?product=gnome-commander", GDK_CURRENT_TIME, &error))
+    if (!gtk_show_uri (NULL, "https://gitlab.gnome.org/GNOME/gnome-commander/issues", GDK_CURRENT_TIME, &error))
         gnome_cmd_error_message (_("There was an error reporting problem."), error);
 }
 
@@ -2001,7 +1967,7 @@ void help_about (GtkMenuItem *menuitem, gpointer not_used)
 
     static const gchar copyright[] = "Copyright \xc2\xa9 2001-2006 Marcus Bjurman\n"
                                      "Copyright \xc2\xa9 2007-2012 Piotr Eljasiak\n"
-                                     "Copyright \xc2\xa9 2013-2018 Uwe Scholz";
+                                     "Copyright \xc2\xa9 2013-2019 Uwe Scholz";
 
     static const gchar comments[] = N_("A fast and powerful file manager for the GNOME desktop");
 
