@@ -2,7 +2,7 @@
  * @file imageloader.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2018 Uwe Scholz\n
+ * @copyright (C) 2013-2019 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -59,14 +59,14 @@ static const gchar *pixmap_files[NUM_PIXMAPS] = {"",
                                                  "gnome_cmd_arrow_down.xpm",
                                                  "gnome_cmd_arrow_blank.xpm",
 
-                                                 "gnome-commander.xpm",
+                                                 "gnome-commander.svg",
                                                  "exec_wheel.xpm",
                                                  "menu_bookmark.xpm",
 
                                                  "overlay_symlink.xpm",
                                                  "overlay_umount.xpm",
 
-                                                 "internal-viewer.xpm"};
+                                                 "internal-viewer.svg"};
 
 
 static const gchar *categories[][2] = {{"text", "gnome-text-plain.png"},
