@@ -2,7 +2,7 @@
  * @file owner.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2018 Uwe Scholz\n
+ * @copyright (C) 2013-2019 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -123,7 +123,7 @@ inline GnomeCmdOwner::HashTable<T,ID>::HashTable()
 }
 
 template <typename T, typename ID>
-inline GnomeCmdOwner::HashTable<T,ID>::~HashTable()
+GnomeCmdOwner::HashTable<T,ID>::~HashTable()
 {
     g_hash_table_destroy (id_table);
     g_hash_table_destroy (name_table);
