@@ -2,7 +2,7 @@
  * @file plugin_manager.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2018 Uwe Scholz\n
+ * @copyright (C) 2013-2019 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,6 +44,7 @@ static GdkBitmap *exec_mask = NULL;
 static GdkPixmap *blank_pixmap = NULL;
 static GdkBitmap *blank_mask = NULL;
 
+gchar* get_plugin_config_location();
 
 static void load_plugin (PluginData *data)
 {
@@ -219,9 +220,11 @@ void plugin_manager_init ()
     }
 
     // find user plugins
-    gchar *user_dir = g_build_filename (g_get_home_dir (), "." PACKAGE "/plugins", NULL);
-    create_dir_if_needed (user_dir);
-    scan_plugins_in_dir (user_dir);
+    gchar *user_dir = get_plugin_config_location();
+    if (create_dir_if_needed (user_dir))
+    {
+        scan_plugins_in_dir (user_dir);
+    }
     g_free (user_dir);
 
     // find system plugins
@@ -461,3 +464,37 @@ void plugin_manager_show ()
     gtk_window_set_resizable ((GtkWindow *) GTK_WIDGET (dialog), TRUE);
     gtk_widget_show_all (GTK_WIDGET (dialog));
 }
+
+gchar* get_plugin_config_location()
+{
+    gchar* returnString {NULL};
+
+    string userPluginConfigDir = get_package_config_dir();
+    userPluginConfigDir += (char*) "/plugins";
+
+    auto dir_exists = is_dir_existing(userPluginConfigDir.c_str());
+
+    switch (dir_exists)
+    {
+        case 0:
+        {
+            if (create_dir_if_needed (userPluginConfigDir.c_str()))
+            {
+                returnString = g_strdup(userPluginConfigDir.c_str());
+            }
+            break;
+        }
+        case 1:
+        {
+            returnString = g_strdup(userPluginConfigDir.c_str());
+            break;
+        }
+        case -1:
+        default:
+        {
+            break;
+        }
+    }
+
+    return returnString;
+}
