@@ -2,7 +2,7 @@
  * @file utils.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2018 Uwe Scholz\n
+ * @copyright (C) 2013-2019 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -882,20 +882,6 @@ gchar *unix_to_unc (const gchar *path)
 }
 
 
-gchar *unc_to_unix (const gchar *path)
-{
-    g_return_val_if_fail (path != NULL, NULL);
-    g_return_val_if_fail (path[0] == '\\', NULL);
-    g_return_val_if_fail (path[1] == '\\', NULL);
-
-    gchar *out = (gchar *) g_malloc(strlen(path));
-    strcpy (out, path+1);
-    transform (out, '\\', '/');
-
-    return out;
-}
-
-
 GdkColor *gdk_color_new (gushort r, gushort g, gushort b)
 {
     GdkColor *c = g_new0 (GdkColor, 1);
@@ -940,8 +926,12 @@ GList *file_list_to_info_list (GList *files)
     return infos;
 }
 
-
-gboolean create_dir_if_needed (const gchar *dpath)
+/**
+ * returns  1 if dir is existing,
+ * returns  0 if dir is not existing,
+ * returns -1 if dir is not readable
+ */
+int is_dir_existing(const gchar *dpath)
 {
     g_return_val_if_fail (dpath, FALSE);
 
@@ -951,21 +941,55 @@ gboolean create_dir_if_needed (const gchar *dpath)
     {
         if (errno == ENOENT)
         {
-            g_print (_("Creating directory %s… "), dpath);
-            if (mkdir (dpath, S_IRUSR|S_IWUSR|S_IXUSR) == 0)  return TRUE;  else
-            {
-                gchar *msg = g_strdup_printf (_("Failed to create the directory %s"), dpath);
-                perror (msg);
-                g_free (msg);
-            }
+            return 0;
         }
         else
             g_warning (_("Couldn’t read from the directory %s: %s"), dpath, strerror (errno));
 
-        return FALSE;
+        return -1;
     }
 
     closedir (dir);
+    return 1;
+}
+
+
+gboolean create_dir_if_needed (const gchar *dpath)
+{
+    g_return_val_if_fail (dpath, FALSE);
+
+    auto dir_exists = is_dir_existing(dpath);
+
+    switch (dir_exists)
+    {
+        case -1:
+        {
+            return FALSE;
+        }
+        case 0:
+        {
+            g_print (_("Creating directory %s… "), dpath);
+            if (mkdir (dpath, S_IRUSR|S_IWUSR|S_IXUSR) == 0)
+            {
+                return TRUE;
+            }
+            else
+            {
+                gchar *msg = g_strdup_printf (_("Failed to create the directory %s"), dpath);
+                perror (msg);
+                g_free (msg);
+                return FALSE;
+            }
+            break;
+        }
+        case 1:
+        default:
+        {
+            return TRUE;
+        }
+    }
+
+    // never reached
     return TRUE;
 }
 
@@ -1211,3 +1235,20 @@ gint get_string_pixel_size (const char *s, int len)
 
     return xSize;
 }
+
+
+gboolean move_old_to_new_location(const gchar* oldPath, const gchar* newPath)
+{
+    if (rename(oldPath, newPath) == 0)
+    {
+        return TRUE;
+    }
+    g_warning (_("Couldn’t move path from “%s” to “%s”: %s"), oldPath, newPath, strerror (errno));
+
+    return FALSE;
+}
+
+gchar* get_package_config_dir()
+{
+    return g_build_filename (g_get_user_config_dir(), PACKAGE, NULL);
+}
\ No newline at end of file
