@@ -2,7 +2,7 @@
  * @file utils.h 
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2018 Uwe Scholz\n
+ * @copyright (C) 2013-2019 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,6 +35,8 @@
 #include "gnome-cmd-app.h"
 #include "utils-no-dependencies.h"
 
+using namespace std;
+
 #define TRACE(s)  std::cout << __FILE__ "(" << __LINE__ << ") " << __PRETTY_FUNCTION__ << "\t" #s ": `" << (s) << "'" << std::endl
 
 extern gchar *debug_flags;
@@ -212,11 +214,11 @@ GtkWidget *create_ui_pixmap (GtkWidget *window,
                              GtkIconSize size);
 
 gchar *unix_to_unc (const gchar *path);
-gchar *unc_to_unix (const gchar *path);
 GdkColor *gdk_color_new (gushort r, gushort g, gushort b);
 GList *file_list_to_uri_list (GList *files);
 GList *file_list_to_info_list (GList *files);
 
+int is_dir_existing(const gchar *dpath);
 gboolean create_dir_if_needed (const gchar *dpath);
 void fix_uri (GnomeVFSURI *uri);
 
@@ -412,3 +414,7 @@ inline std::string join(const COLL<T, Compare, Allocator> &coll, const std::stri
 }
 
 gint get_string_pixel_size (const char *s, int len);
+
+gboolean move_old_to_new_location(const gchar* oldPath, const gchar* newPath);
+
+gchar* get_package_config_dir();
\ No newline at end of file
